@@ -3,3 +3,6 @@ RAW_HTTP_BODY_BYTES = "RawHttpBodyBytes"
 TYPED_DATA_COLLECTION = "TypedDataCollection"
 RPC_HTTP_BODY_ONLY = "RpcHttpBodyOnly"
 RPC_HTTP_TRIGGER_METADATA_REMOVED = "RpcHttpTriggerMetadataRemoved"
+
+# Feature Flags (app settings)
+PYTHON_ROLLBACK_CWD_PATH = "PYTHON_ROLLBACK_CWD_PATH"
